.. Goldilocks documentation master file, created by
   sphinx-quickstart on Mon Aug 18 19:19:01 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Goldilocks's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   examples
   advanced
   exporting
   plotting
   custom
   contributing
   authors
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

